/*
 *  wiidev_client.h
 *  WiiDev
 *
 *  Created by Ian Rickard on 2/20/07.
 *  Copyright 2007 __MyCompanyName__. All rights reserved.
 *
 */

#ifndef WIIDEV_H
#define WIIDEV_H


typedef unsigned char WiiDevData[];
typedef void (*WiiDevMemReadCallback)(int address, WiiDevData data, int length);
typedef void (*WiiDevDataCallback)(WiiDevData data, int length);

typedef struct WiiDev {
	struct {
		int x, y, z;
	} xlrraw;
	struct {
		int x, y, z;
	} xlrzero;
	struct {
		int x, y, z;
	} xlrone;
	struct {
		float x, y, z;
	} xlr;
	int buttons;
	struct {
		int active, x, y, s;
	} irdata[4];
	
	int lastUpdateMask;
	
	// private:
	int sock;
	WiiDevDataCallback dataCallback;
	WiiDevMemReadCallback memCallback;
	int waitingForXlrCal;
	int regs[0x20];
	int vibe;
} *WiiDevRef;

WiiDevRef WiiDevNewFromName(const char *name);
void WiiDevRelease(WiiDevRef ref);

// handle any incoming data
int WiiDevUpdate(WiiDevRef ref);
// positive return: number of updates processed.  negative: error.

void WiiDevSetReport(WiiDevRef ref, int report);
void WiiDevEnableContinuousReporting(WiiDevRef ref, int on);
void WiiDevEnableVibration(WiiDevRef ref, int on);
void WiiDevEnableIR(WiiDevRef ref, int mode);
void WiiDevSetLEDs(WiiDevRef ref, int leds);


void WiiDevSetMemReadCallback(WiiDevRef ref, WiiDevMemReadCallback callback);
void WiiDevReadMem(WiiDevRef ref, int address, int length);
void WiiDevWriteMem(WiiDevRef ref, int address, WiiDevData data, int length);


// low level
void WiiDevWriteReg(WiiDevRef ref, int reg);
void WiiDevSend(WiiDevRef ref, WiiDevData data, int length);
void WiiDevSetDataReceivedCallback(WiiDevRef ref, WiiDevDataCallback callback);



#endif